import request from "@/utils/request";
// 人员列表接口
export function PersonList(data) {
  return request({
    url: "/Api/Person/GetBillList",
    method: "post",
    data,
  });
}
// 获取人员by角色id
export function personListByRole(data) {
  return request({
    url: "/api/Person/GetPersonByRole",
    method: "post",
    data,
  });
}

// 获取详情
export function PersonDetail(data) {
  return request({
    url: "/Api/Person/GetBillData",
    method: "post",
    data,
  });
}
// 编辑
export function PersonSaveData(data) {
  return request({
    url: "/Api/Person/SaveData",
    method: "post",
    data,
  });
}
// 删除
export function PersonDelData(data) {
  return request({
    url: "/Api/Person/DelData",
    method: "post",
    data,
  });
}
// 人员启用
export function PersonOpen(data) {
  return request({
    url: "/Api/Person/Open",
    method: "post",
    data,
  });
}
// 人员停用
export function PersonClose(data) {
  return request({
    url: "/Api/Person/Close",
    method: "post",
    data,
  });
}
